import request from "@/utils/request";

// 查询设备列表
export function listDevice(query) {
  return request({
    url: "/iot/device/list",
    method: "get",
    params: query,
  });
}

// 查询设备详细
export function getDevice(deviceId) {
  return request({
    url: "/iot/device/" + deviceId,
    method: "get",
  });
}

// 新增设备
export function addDevice(data) {
  return request({
    url: "/iot/device",
    method: "post",
    data: data,
  });
}

// 修改设备
export function updateDevice(data) {
  return request({
    url: "/iot/device",
    method: "put",
    data: data,
  });
}

// 删除设备
export function delDevice(deviceId) {
  return request({
    url: "/iot/device/" + deviceId,
    method: "delete",
  });
}

export function fetchOperatingStatus(deviceSn) {
  return request({
    url: `/iot/device/runInfo/${deviceSn}`,
    method: "GET",
  });
}

/**
 * 查询设备物模型某一指标历史
 * @param params
 * @return {*}
 */
export function selectIdentifierHistory(params) {
  let start_time = null;
  let end_time = null;
  if (params.startTime) start_time = new Date(params.startTime).getTime();
  if (params.endTime) end_time = new Date(params.endTime).getTime();
  return request({
    url: `/iot/device/selectIdentifierHistory/${params.deviceSn}`,
    method: "GET",
    params: {
      pageNum: params.pageNum,
      pageSize: params.pageSize,
      identifier: params.identifier,
      type: params.type,
      startTime: start_time,
      endTime: end_time,
      sort: params.sort,
    },
  });
}

export function setDeviceAttr(data) {
  const { version, method, params } = data;
  return request({
    url: `/iot/device/set/${data.productSn}/${data.deviceSn}`,
    method: "post",
    data: {
      version,
      method,
      params,
    },
  });
}

export function setDeviceInvoke(data) {
  const { version, method, params } = data;
  return request({
    url: `/iot/device/invoke/${data.productSn}/${data.deviceSn}`,
    method: "post",
    data: {
      version,
      method,
      params,
    },
  });
}

/**
 * 属性设置日志列表
 * @param params
 * @return {*}
 */
export function setPropertyLog(params) {
  return request({
    url: `/device/setPropertyLog/list`,
    params,
  });
}

/**
 * 服务调用日志列表
 * @return {*}
 * @param params
 */
export function setFunctionLog(params) {
  return request({
    url: `/device/setFunctionLog/list`,
    params,
  });
}
