import { defineStore } from "pinia";
import { cloneDeep } from "lodash-es";

const useNotificationStore = defineStore("notification", {
  state: () => ({
    unreadList: [],
  }),
  actions: {
    pushItem(row) {
      const _row = cloneDeep(row);
      const isNotExisted = this.unreadList.every(
        (el) => el.msgId !== _row.msgId
      );
      if (isNotExisted) {
        this.unreadList.unshift(_row);
      }
    },
    pushItems(rows) {
      for (const row of rows) {
        const _row = cloneDeep(row);
        const isNotExisted = this.unreadList.every(
          (el) => el.msgId !== _row.msgId
        );
        if (isNotExisted) {
          this.unreadList.push(_row);
        }
      }
    },
    removeItem(id) {
      this.unreadList = this.unreadList.filter((el) => el.msgId !== id);
    },
  },
  getters: {
    getList: (state) => {
      return (params) =>
        state.unreadList.slice(
          (params.pageNum - 1) * params.pageSize + 1,
          (params.pageNum - 1) * params.pageSize + 1 + params.pageSize
        );
    },
    unreadCount: (state) => state.unreadList.length,
  },
  persist: true,
});

export default useNotificationStore;
